% Author: Andreas Meese, Trondheim 21.02.2013
% 'Winter is coming'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script description:
% find number of cycles for a season given input parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tic
clc
clear all
close all
%% location of input file and subfunctions
% location of program (inputfile must be in same path as main.m)
folder = 'C:\Users\Andreas\Dropbox\NTNU\Master\Program\';
% location of outputfolder
outputloc = ...
    'C:\Users\Andreas\Dropbox\NTNU\Master\Report\latex\figures\Results';
% Make folders with following names in the output folder:
opfolders = ['\ice';'\ons';'\vib';'\frc';'\dyn';'\cmp'];
% name of inputfiles
inputfile = 'input.txt';
data1 = 'A_0203';
data2 = '03_3003_0400_122500_122800';
addpath(strcat(folder,'input'))
addpath(strcat(folder,'subfunctions'))  %related to general input
addpath(strcat(folder,'subfunctions2')) %related to the 30.03 event
addpath(strcat(folder,'plotfunctions')) %location of plotting functions

resolution = '-r600'; %resolution on plots if using print as function

%% Read input
% read input and the Luleaa data
input = rinput(outputloc,opfolders,inputfile,data1); 
% load full scale data 30.03.03 event
event = loadevent(data2);

%% Wind statistics
% a 24 hr avg of the wind direction is to be used further to find ice 
% drift
windprop = wind(input);

%% Calculate parameters based on ISO etc
% Calculate ice growth, ice velocity,drift direction and ice temperature
iceprop = iceproperties(input,windprop);
     
% Calculate global ffatiorce on a vertical structure
force = verticalforces(input,iceprop);

%% Find onset criteria for FLC and number of vibrations
FLC = onset(input,iceprop,force);

%% Estimate fatigue damage and fatigue life
fatigue = fatiguecalc(input,iceprop,force,FLC);

%% Dynamic response to FLC
dynamic2 = dynresponse2(input,event);

%% Process the 30.03.2003 event
flcevent = processevent(input,iceprop,event);


%% Plots
windplots(input,windprop,iceprop)
iceplots(input,iceprop,windprop);                   
onsetplot(input,iceprop,FLC)                  
vibrationplot(input,iceprop,FLC);
fatigueplot(input,fatigue);
forceplots(input,iceprop,force);            
dynamicplots(input,iceprop,FLC,force,dynamic2) %used to see SDOFresponse
comparisonplots(input,dynamic2,flcevent)

toc




