% Subprogram to the program icemain.m
% Author: Andreas Meese, Bergen 28.02.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%subplot(2,1,1)
%% EMIR SIN MAATE
function [] = iceplots(input,ice,wind)

months = ['Jul';'Oct';'Jan';'Apr';'Jul'];
months2 = ['Sep';'Oct';'Nov';'Dec';'Jan';'Feb';'Mar';'Apr';'May'];
months3 = ['Nov';'Dec';'Jan';'Feb';'Mar';'Apr';'May'];
%A(1,1:6) = 0
%axis([XMIN XMAX YMIN YMAX])
copy_to_folder = input.outputloc(1,:);
fontsize=input.fontsize;
L = length(ice.thick);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Air temperature and ice thickness
figure(1)
subplot(2,1,1)
hold on
plot(input.fs.temp,'Color','k')
set(gca,'FontSize',fontsize)
set(gca,'XTick',1:722.5:L)
set(gca,'XTickLabel',months)
axis([0 L -32 30])
title('Air temperature')
ylabel('T_{air} (\,^{\circ}C)')
% Add a horizontal line for the input temperature 
line([0;length(input.fs.temp)],...
    [input.phys.water(1);input.phys.water(1)],'Color',[0 0 0])
%legend('Average','Freezing temp','Location','Best')
box off
% set(gcf, 'PaperPositionMode', 'manual');
% set(gcf, 'PaperUnits', 'centimeters');
% set(gcf, 'PaperPosition', [0 0 16 12]);
hold off

subplot(2,1,2)
hold on
plot(ice.thick,'Color','k')
set(gca,'FontSize',fontsize)
set(gca,'XTick',1:722.5:L)
set(gca,'XTickLabel',months)
% xlabel('Time')
axis([1 L 0 1.0])
title('Ice thickness')
ylabel('h_{ice} (m)')
box off
% set(gcf, 'PaperPositionMode', 'manual');
% set(gcf, 'PaperUnits', 'centimeters');
% set(gcf, 'PaperPosition', [0 0 16 12]);
matlab2tikz('filename',strcat(copy_to_folder,'\airvsthick.tex'),...
    'showInfo',false,'height','\figureheight','width','\figurewidth')

%% ice drift
driften = ice.icedrift(2,:);
for j = 1:length(driften)
    if driften(j) > 2*pi
        driften(j) = driften(j) - 2*pi;
    end
end
figure(2)
subplot(2,1,1)
hold on
set(gca,'FontSize',fontsize)
set(gca,'XTick',60:30:300)
set(gca,'XTickLabel',months2)
axis([75 305 0 360])
ylabel('\theta_{ice} (\,^{\circ})')
title('Ice drift direction')
plot(driften*180/pi,'Color','k')
box off
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 16 12]);
hold off

subplot(2,1,2)
hold on
set(gca,'FontSize',fontsize)
set(gca,'XTick',60:30:300)
set(gca,'XTickLabel',months2)
axis([75 305 0 0.165])
ylabel('V_{ice} (m/s)')
title('Ice drift velocity')
plot(ice.icedrift(1,:),'Color','k')
box off
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 16 12]);
hold off
matlab2tikz('filename',strcat(copy_to_folder,'\icedrift.tikz')...
    ,'showInfo',false,'height','\figureheight','width','\figurewidth')


%% global pressure for sea ice
figure(4)
hold on
set(gca,'FontSize',fontsize)
set(gca,'XTick',120:30:300)
set(gca,'XTickLabel',months3)
axis([134 299 0 2.2])
plot(ice.pg,'Color','k')
%title('Global pressure for sea ice')
ylabel('p_{G} (MPa)')
% Add a horizontal line for the input temperature 
line([0;length(input.fs.temp)],...
    [input.phys.water(1);input.phys.water(1)],'Color',[0 0 0])
% legend('Average','Freezing temp','Location','SouthEast')
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 20 10]);
matlab2tikz('filename',strcat(copy_to_folder,'\globalpressure.tikz')...
    ,'showInfo',false,'height','\figureheight','width','\figurewidth')
hold off

%% aspect ratio between D and hice
figure(47)
hold on
set(gca,'FontSize',fontsize)
set(gca,'XTick',1:90:L/8)
set(gca,'XTickLabel',months)
axis([89 300 0 150])
ylabel('D/h_{ice} (-)')
plot(ice.aspectratio,'Color','k','LineStyle','--')
line([0;300],[40;40],'Color',[0 0 0],'LineStyle','-')
legend('Ratio','Boundary between regimes',...
    'Location','NorthEast')
matlab2tikz('filename',strcat(copy_to_folder,'\aspect.tikz')...
    ,'showInfo',false,'height','\figureheight','width','\figurewidth')
hold off

%% modeshape
figure(101)
% Create axes
%% Uncomment the following line to preserve the X-limits of the axes
% xlim(axes1,[0 1]);
%% Uncomment the following line to preserve the Y-limits of the axes
% ylim(axes1,[0 42.3]);
plot(input.str.modeshape1(:,2),input.str.modeshape1(:,1),'k')
box off
% Create xlabel
xlabel('\phi_{1}(z)','FontSize',12);
% Create title
% title('1^{st} mode shape','FontSize',12);
stringen = ...
    'C:\Users\Andreas\Dropbox\NTNU\Master\Report\latex\figures\theory';
% Create ylabel
ylabel('z (m)','FontSize',12);
matlab2tikz('filename',strcat(stringen,'\modeshape1.tex')...
    ,'showInfo',false,'height','\figureheight','width','\figurewidth')


end