% Calculate dynamic response of SDOF model
% given full scale measured parameters from 12:26:00 to 12:26:40 for 
% 30.03.2003 event
% Subprogram to icemain.m
% Author: Andreas Meese, Tr.heim 16.05.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[result] = dynresponse2(input,event)

thickness = event.thickness.t(13:22);  %measured thickness vector

f1 = input.str.freq(2);
M1 = input.str.strice(1)/(input.str.strice(3)^2);
%time length of simulation
t = 40;        
%time between each measurement
TSTEP = t/length(thickness);
%time step simulation
tstep = input.sim.time(2); 
%lower and upper q values (coefficient)
q = 0.25;%input.sim.q(1);          
% iso = FLC.method5(1,:);      %vector with 0 and 1's (critieria fulfilm.)

%% maximum force at time of flc event 30.03.2003
    pg = zeros(1,length(thickness));
    staticmax = zeros(1,length(thickness));
    staticmin = zeros(1,length(thickness));
    deltaf = zeros(1,length(thickness));
    m = -0.16;              %empirical coefficient
    h1 = 1.0;               %reference thickness 
    for j = 1:length(pg)
       if input.str.diam/thickness(j) > 40
           pg(j) = 0;
       else
           if thickness(j) < 1.0
              n = -0.50 + thickness(j)/5; 
           elseif thickness(j) >= 1.0
              n = -0.30; 
           end
           pg(j) = input.phys.Cr*((thickness(j)/h1)^n)*...
           ((input.str.diam/thickness(j))^m);           
       
           staticmax(j) = pg(j)*thickness(j)*input.str.diam*10^6;
           staticmin(j) = staticmax(j)*(1-q);
           deltaf(j) = staticmax(j)*q;
       end
    end  

%timevector and force vector establishment
result.timevector = 0:tstep:t;
% result.timevector = 0:t/length(event.thickness.timevector):t;
J = length(result.timevector);

%% Load history given measured thickness
% result.F = zeros(1,J);
temp1 = 1;
temp2 = ceil(TSTEP/tstep);
steget = ceil(TSTEP/tstep);
for i = 1:size(staticmax,2)
result.zet1(temp1:temp2) = staticmax(i);
result.zet2(temp1:temp2) = staticmin(i);
result.zetdF(temp1:temp2) = staticmax(i)*q;
temp1 = temp1+steget;
temp2 = temp2+steget;

end

floor(J/floor(TSTEP/tstep));
result.F = zeros(1,length(result.zet1));
for i=1:J
    result.F(i) = result.zet1(i) + ...
        result.zetdF(i)*((sawtooth(2*pi*f1*result.timevector(i))-1)/2);
end

% %response vectors establishment
result.u = zeros(1,J); result.udot = result.u; 
result.u2dot = result.u;
% 
dt = tstep;                     %sample time
Fs = 1/dt;                      %sample frequency
L = length(result.u2dot);       %length of signal

%fft vectors establishment
result.fftacc = zeros(1,L);
result.freq = zeros(1,L);
result.fftamp = zeros(1,L);
% 
%% Dynamic response of a SDOF model of the waterline
% Newmarks method to solve the equation of forced motion
xi = input.str.xi1(1);        %fraction of critical damping
wn = 2*pi*f1;                 %circular frequency
P = result.F(1,:);            %force vector in Newtons
M = M1;                       %system mass
K = M*wn^2;                   %system stiffness
C = 2*xi*wn*M;                %system damping
dt = input.sim.time(2);       %time step
beta = input.sim.newmark(1);  %beta in newmarks method
gamma = input.sim.newmark(2); %gamma in newmarks method

u0 = input.sim.initial(1);    %initial displacement
udot0 = input.sim.initial(2); %initial velocity

kgor = K + gamma/(beta*dt)*C + M/(beta*dt^2);
a = M/(beta*dt) + gamma*C/beta;
b = 0.5*M/beta + dt*(0.5*gamma/beta -1)*C;

dp = diff(P);

result.u(1) = u0;
result.udot(1) = udot0;
result.u2dot(1) = 1/M*(P(1)-K*u0-C*udot0);

for i = 1:(length(result.timevector)-1)
    deltaF = dp(i) + a*result.udot(i) + b*result.u2dot(i);
    du_i = deltaF/kgor;
    dudot_i = gamma/(beta*dt)*du_i - gamma/beta*result.udot(i) + ...
        dt*(1-0.5*gamma/beta)*result.u2dot(i);
    du2dot_i = 1/(beta*dt^2)*du_i - 1/(beta*dt)*result.udot(i) - ...
        0.5/beta*result.u2dot(i);
    result.u(i+1) = du_i + result.u(i);
    result.udot(i+1) = dudot_i + result.udot(i);
    result.u2dot(i+1) = du2dot_i + result.u2dot(i);
end

%% Fourier transform of acceleration
% for j = 1:2
NFFT = 2^nextpow2(L); % Next power of 2 from length of y
abc = result.u2dot(1,:);
result.fftacc = fft(abc,NFFT)/L;
result.freq = Fs/2*linspace(0,1,NFFT/2+1);
% amplitude of the one sided spectrum
result.fftamp = 2*abs(result.fftacc(1:NFFT/2+1));

% disp('velocities')
% min(result.udot)
% max(result.udot)
% disp('acc')
% min(result.u2dot)
% max(result.u2dot)
end
    

