% Calculate ice thickness growth, ice velocity and drift direction 
% for input temperature and for measured
% temperature. Subprogram to program icemain.m
% Author: Andreas Meese, Bergen 28.02.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[result] = iceproperties(input,windprop)

% INPUTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T = input.fs.temp;          % Ambient air temperature
% Relation between wind speed and ice drift speed
IW_coeff = input.drift.geostrophic(1);
% Geostrophic relation between wind and ice
theta_g = input.drift.geostrophic(2)*pi()/180; 
f_water = input.phys.water(1);   % freezing temperature of water
D = input.str.diam;              % structural width
f_meas = input.proc.fmeas;       % measuring frequency
P = 8;                           % 2 avg pr day, 8 gives 1 avg pr day

% OUTPUTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Ice thickness and FDD
    L = length(T); % size of the measured temperature vector
    result.thick = zeros(1,L);
    result.FDD = zeros(1,L);

    for i = 1:L
        if i==1
            % only using temperatures below zero
            if T(i) <= f_water
            result.FDD(i) = (1/f_meas)*(f_water-T(i));

            else
            result.FDD(i) = 0;

            end

        else
            if T(i) <= f_water
            result.FDD(i) = result.FDD(i-1) + (1/f_meas)*(f_water-T(i));

            else
            result.FDD(i) = result.FDD(i-1) + 0;

            end
        end

    end

    for j = 1:input.proc.ilength(1)
        result.FDD(i) = 0;
    end
    for j = input.proc.ilength(2):length(result.FDD(i))
        result.FDD(i) = 0;
    end

    for i = 1:L

        if i==1
            if result.FDD(i) == 0
            result.thick(i) = 0;
            else
            a=1;
            b=-50;
            c=-8*result.FDD(i);
            %zubovs formula (centimeters)
            result.thick(i) = (-b-sqrt((b^2)-4*a*c))/(200*a);           
            end

        else
            if result.FDD(i) == 0
            result.thick(i) = result.thick(i-1) + 0;
            else
            a=1;
            b=-50;
            c=-8*result.FDD(i);
            %zubovs formula (centimeters)
            result.thick(i) = (-b-sqrt((b^2)-4*a*c))/(200*a);           
            end         
        end
    end
    result.thick = (-1).*result.thick;   

%% Ice speed and drift direction
% Calculated 24hr average of the wind -> 365 days w/ 8 measurings pr day
% convert to radians since matlab operates with radians
% the ice drift vector; row 1 is speed, row 2 is direction in degrees
result.icedrift = zeros(2,L/8);
for j = 1:L/P
    result.icedrift(1,j) = windprop.avgwind(j,1)*IW_coeff;
    %converting from deg to rad
    result.icedrift(2,j) = windprop.avgwind(j,2) + theta_g;
end

%% Define the start and end of the winter season
        for j = 1:input.proc.ilength(1)
        result.FDD(j)=0;
        result.thick(j)=0;
       % result.pg(j) = 0;
        result.aspectratio(j) = 0;
        %result.icedrift(:,j) = 0;
        end
        for j = input.proc.ilength(2):length(result.thick)
        result.FDD(j)=0;
        result.thick(j)=0;           
       % result.pg(j) = 0;
        result.aspectratio(j) = 0;
        %result.icedrift(:,j) = 0;
        end             

% Daily average ice thickness and air temp
result.ticeavg = zeros(1,L/P);
result.tempavg = zeros(1,L/P);
for j = 1:L/P
    if j == 1
        a = 1;
        b = P;
        sum1=0;
        sum2=0;
        for i = a:b
            sum1 = sum1 + result.thick(i);
            sum2 = sum2 + input.fs.temp(i);
        end
        result.ticeavg(1,j) = sum1/P;    
        result.tempavg(1,j) = sum2/P;    
    else
        a = a+P;
        b = b+P;
        sum1=0;
        sum2=0;
        for i = a:b
            sum1 = sum1 + result.thick(i);
            sum2 = sum2 + input.fs.temp(i);
        end
        result.ticeavg(1,j) = sum1/P;
        result.tempavg(1,j) = sum2/P;    
    end
    % no ice thickness -> no drift velocity
    if result.ticeavg(1,j) == 0
       result.icedrift(:,j) = 0;
    end
end

%% Global pressure , daily avg.
    result.pg = zeros(1,L/P);
    result.aspectratio = zeros(1,L/P);
    m = -0.16;              %empirical coefficient
    h1 = 1.0;               %reference thickness 
    for j = 1:L/P
       if result.ticeavg(j) == 0;
           result.pg(j) = 0;
       else
           result.aspectratio(j) = input.str.diam/result.ticeavg(j); 
           if result.aspectratio(j) > 40
               result.pg(j) = 0;
           else
               if result.ticeavg(j) < 1.0
                  n = -0.50 + result.ticeavg(j)/5; 
               elseif result.ticeavg(j) >= 1.0
                  n = -0.30; 
               end
               result.pg(j) = input.phys.Cr*((result.ticeavg(j)/h1)^n)*...
               ((input.str.diam/result.ticeavg(j))^m);         
           end
       end
    end           
end

