% Subprogram for reading the input file the program for icemain.m
% Author: Andreas Meese, Trondheim 21.02.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[input] = rinput(outputloc,folders,filename,data1)

%open the input file
fileid=fopen(filename,'r');

%% Full scale measured environmental parameters
load(data1)
input.fs.temp =  (A_0203(:,5));             %measured air temperature
input.fs.windd = (A_0203(:,3));             %measured wind direction
input.fs.winds = (A_0203(:,4));             %measured wind speed

%% Structural properties
input.str.diam = fscanf(fileid,'%f',1);     %waterline diameter in meters
input.str.freq = fscanf(fileid,'%f',4);     %1st. translational freq
input.str.guo = fscanf(fileid,'%f',3);      %nodal mass (guo) and freq wl
input.str.strice = fscanf(fileid,'%f',4);   %SDOF M (kg), freq and K  (N/m)
input.str.xi1 = fscanf(fileid,'%f',2);      %SDOF damping% of critical
input.str.height = fscanf(fileid,'%f',1);   %tower height
input.str.wl = fscanf(fileid,'%f',1);       %waterline level (m)
input.str.Acontact = fscanf(fileid,'%f',2); %Reference A for pressure (m2)
input.str.Aface = fscanf(fileid,'%f',1);    %face area of structure
input.str.modeshape1 = fscanf(fileid,'%f %f',[15 2]);  %modeshape of sdof
input.str.kwaterline = fscanf(fileid,'%f',1); %waterline stiffness, strice
input.str.dwlbond = fscanf(fileid,'%f',1); %static displ. boundary FLC (m)
input.str.weightabovecs = fscanf(fileid,'%f',1); %weight above cs cons.

%% Parameters related to reinforced concrete and the steel
input.concrete.r_outer = fscanf(fileid,'%f',1); %outer diameter (m)
input.concrete.thick = fscanf(fileid,'%f',1);   %concrete thickness (m)

%% Parameters related to fatigue life
input.fat.designload=fscanf(fileid,'%f',1); %design load for waterline MN/m
input.fat.SN = fscanf(fileid,'%f',2); %k1 and k2 for ribbed steel
input.fat.klimitsigma = fscanf(fileid,'%f',2); %limit betw. k1 and k2. and
% limit between low and high-cycle range
input.fat.highlow = fscanf(fileid,'%f',1); %limit betw. high and low cycle
input.fat.rsyieldlim = fscanf(fileid,'%f',1); %yield for ribbed steel
% observed nr. of cycles and ice thickness at the time
input.fat.obsyclethick = fscanf(fileid,'%f',2); %nr. and m

%% Wind drift speed and direction
%1 is coefficient between ice and wind, 2 is geostrophic relation
input.drift.geostrophic = fscanf(fileid,'%f',2);    
%upper and lower boundary for the ice drifts ability to move
input.drift.boundaries = fscanf(fileid,'%f',2);     
% 
%% Physical parameters
input.phys.water = fscanf(fileid,'%f',2);     %1 is t_freeze, 2 is density
input.phys.Cr = fscanf(fileid,'%f',1);        %ice strength coefficient
% 
%% Input parameters for FLC criteria
%upper and lower dimensionless boundary for thickness
input.flc.Tdim = fscanf(fileid,'%f',2);   
%upper and lower dimensionless boundary for diameter
input.flc.Ddim = fscanf(fileid,'%f',2);  
%max lock in duration per event
input.flc.dur = fscanf(fileid,'%f',1);   
%
%% processing properties
input.proc.length = fscanf(fileid,'%f',2);   %length of winter in days
input.proc.fmeas = fscanf(fileid,'%f',1);    %measurements per day
input.proc.ilength = [input.proc.length(1)*input.proc.fmeas ...
input.proc.length(2)*input.proc.fmeas];      %season length in indexes
input.fontsize = fscanf(fileid,'%f',1);      %fontsize on plots
%
%% Simulation properties for dynamic response to FLI
input.sim.time = fscanf(fileid,'%f',2);   %time length and time step
input.sim.q = fscanf(fileid,'%f',2);   %upper and lower parameter for Fmin
input.sim.gamma = fscanf(fileid,'%f',1);%ice velocity to response velocity
input.sim.newmark = fscanf(fileid,'%f',2);%beta and gamma in Newmarks met.
input.sim.initial = fscanf(fileid,'%f',2);%initial displ. and velocity
input.steadyevent = fscanf(fileid,'%f',2);%start and stop of steadystate
input.sevent = fscanf(fileid,'%f',2);     %start and stop for ss 30.03
%
%define the output paths
input.outputloc = strcat(outputloc,folders);

end

