% Calculate force on structure given structural properties, ice properties.
% Subprogram to program icemain.m
% Author: Andreas Meese, Bergen 28.02.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[result] = verticalforces(input,ice)

% INPUTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% assume biaxial stiffness 
% Structural properties
D = input.str.diam;             %structural diameter (cylinder) (meters)
h_wl = input.str.wl;            %waterline height above seabed
A1 = input.str.Acontact(1);     % contact area 1 (m2)
A2 = input.str.Acontact(2);     % contact area 2 (m2)
t_ice = ice.ticeavg;              % Ice thickness. vector [1:2920]

%waterline stiffness of norstromsgrund by STRICE-report (karna, 2004)
k = input.str.kwaterline;

%length of vector
L = length(t_ice);
  
% OUPUTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% ISO 19906 Vertical structure; page 169 equation A.8-21
% Nominal contact area ( structural width * ice thickness
An = D.*t_ice;
result.FGlobmax = zeros(1,L);
% Global ice action
    for j = 1:L
       result.FGlobmax(j) = ice.pg(j)*An(j);
    end  
  
%%% Displacement of the ligthhouse due to static loading
%result.deltawl = zeros(1,L);

for j = 1:L
    result.deltawl(j) = (10^6).*result.FGlobmax(j)/k; %MN to N
end

% Over Turning Moment (Nm) and Base shear N
result.OTM = zeros(1,L);
result.BS = zeros(1,L);
for j = 1:L
    if j>=input.proc.length(1) && j <= input.proc.length(2)
        result.OTM(j) = result.FGlobmax(j)*h_wl;
        result.BS(j) = result.FGlobmax(j);
    end
end
end
    

