% Subprogram for for main.m. Finds the 24 hrs averages of wind drift 
% direction and velocities.
% Author: Andreas Meese, Trondheim 29.5.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[result] = wind(input)

P=8;    % 4 gives 2 avg per day, 8 gives 1 avg per day
L = length(input.fs.windd)/P;
% measured components
theta_w = circ_ang2rad(input.fs.windd);
v_wind = input.fs.winds;

result.avgwindcomp = zeros(2,L);  %daily avg. of cos and sin components
result.avgwind = zeros(L,2);      %col 1 is avg.speed, col 2 is avg.dir

% convert wind directions to radians

for j = 1:L
    if j == 1
        a = 1;
        b = P;
        sum1=0;
        sum2=0;
        for i = 1:P
            sum1 = sum1 + v_wind(i)*cos(theta_w(i)); %y component
            sum2 = sum2 + v_wind(i)*sin(theta_w(i)); %x component
        end
        result.avgwindcomp(1,j) = sum1/P; %cosine component of vector (y)
        result.avgwindcomp(2,j) = sum2/P; %sine component of vector (x)
    else
        a = a+P;
        b = b+P;
        sum1=0;
        sum2=0;
        for i = a:b
            sum1 = sum1 + v_wind(i)*cos(theta_w(i));
            sum2 = sum2 + v_wind(i)*sin(theta_w(i));
        end
        result.avgwindcomp(1,j) = sum1/P;
        result.avgwindcomp(2,j) = sum2/P;
    end
        result.avgwind(j,1) = sqrt((result.avgwindcomp(1,j)^2) + ...
        (result.avgwindcomp(2,j)^2));
    %std deviation of the 8 vectors
    result.windstdv(j) = std(input.fs.windd(a:b));
end

% find the average direction . 
for j = 1:length(result.avgwind)
    if result.avgwindcomp(2,j) == 0 && result.avgwindcomp(1,j) == 0
        result.avgwind(j,2) = 0;
    elseif result.avgwindcomp(1,j) < 0 
        result.avgwind(j,2) = ...
        atan(result.avgwindcomp(2,j)/result.avgwindcomp(1,j)) + pi();
    elseif result.avgwindcomp(2,j) < 0 && result.avgwindcomp(1,j) > 0
    %avg wind direction
    result.avgwind(j,2) = ...
        atan(result.avgwindcomp(2,j)/result.avgwindcomp(1,j)) + 2*pi();
    %avg wind speed
    end
end

result.alpha_rad = result.avgwind(:,2);
% mean angle
result.alpha_bar = circ_mean(result.alpha_rad);
% median
result.alpha_hat = circ_median(result.alpha_rad);
% std. deviation
% s is angular std
% s0 is circular std
[result.s_alpha,result.s0_alpha] = circ_std(result.alpha_rad);

%{
for j = 1:L/8
    if j == 1
        a = 1;
        b = 8;
        sum1=0;
        sum2=0;
        for i = 1:8
            sum1 = sum1 + v_wind(i)*cos(theta_w(i)); %y component
            sum2 = sum2 + v_wind(i)*sin(theta_w(i)); %x component
        end
        result.avgwindcomp(1,j) = sum1/8; %cosine component of vector (y)
        result.avgwindcomp(2,j) = sum2/8; %sine component of vector (x)
    else
        a = a+8;
        b = b+8;
        sum1=0;
        sum2=0;
        for i = a:b
            sum1 = sum1 + v_wind(i)*cos(theta_w(i));
            sum2 = sum2 + v_wind(i)*sin(theta_w(i));
        end
        result.avgwindcomp(1,j) = sum1/8;
        result.avgwindcomp(2,j) = sum2/8;
    end
        result.avgwind(j,1) = sqrt((result.avgwindcomp(1,j)^2) + ...
        (result.avgwindcomp(2,j)^2));
    %std deviation of the 8 vectors
    result.windstdv(j) = std(input.fs.windd(a:b));
end
%}

end