% Subprogram for reading the input file the program for icemain.m
% Loading fullscale data from the 30.03.2003 event 12:24:30
% Author: Andreas Meese, Trondheim 21.02.2012
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[full] = loadevent(data2)

%% Load environmental parameters
load(data2)

%% Load measured structural parameters 30.03.2003
% Event time information
full.event.start = SubEvent.Load_Time(1,:);
full.event.stop = SubEvent.Load_Time(end,:);
full.event.length = SubEvent.Load_Time(end,:)-SubEvent.Load_Time(1,:);

% Make timevector
n = length(SubEvent.Load_Time); %number of measurements
full.event.seconds = full.event.length(1)*60*60+ ...
    full.event.length(2)*60+full.event.length(3); %time in seconds
% Time vector
time0=(0:(full.event.seconds/(n)):full.event.seconds)'; 
full.time=time0(1:end-1);

% Accelerations 
full.acc.lev19 = SubEvent.Acc(:,3); %sum of accelerations at 19.65 m
full.acc.lev37 = SubEvent.Acc(:,6); %sum of accelerations at 37.10 m 

% Forces
full.totalforce.x = SubEvent.Total(:,3);
full.totalforce.y = SubEvent.Total(:,6);
full.totalforce.sum = SubEvent.Total(:,7);

% Inclination
full.inclination = SubEvent.Inc(:,1:6);

% Load panel forces
full.panelforce = SubEvent.Load_Pan(:,:);

% Load segment
full.loadseg.left = SubEvent.Load_Seg.L(:,1:4);
full.loadseg.right = SubEvent.Load_Seg.R(:,1:4);

%%% Ice thickness
%% thickness time
full.thickness.time = SubEvent.Thick_Time; %hours minutes seconds

% construct time vector for thickness
m = length(full.thickness.time); %number of measurements
full.thickness.tlength=full.thickness.time(end,:)...
    -full.thickness.time(1,:); %length in HH:MM:SS
full.tseconds = full.thickness.tlength(1)*60*60+...
    full.thickness.tlength(2)*60+full.thickness.tlength(3); %seconds
full.thickness.timevector=(0:(full.tseconds/(m)):full.tseconds)'; 
full.thickness.timevector=full.thickness.timevector(1:end-1);
%% Measured ice sheet thickness
% Underside of ice sheet layer by electro-magnetic measuring.
full.thickness.em = SubEvent.Thick_EM; 
% Thickness by upward looking sonar
full.thickness.son = SubEvent.Thick_SON;
% Ice sheet thickness
full.thickness.t = SubEvent.Thickness; 
% Top side of ice sheet layer (vertical pos)
full.thickness.las = SubEvent.Thick_LAS; 
% Thickness by laser and em device
full.thickness.diff = SubEvent.Thick_LAS-SubEvent.Thick_EM; 

%% Environmental parameters
full.env.time = SubEvent.Env_Time(:,1:3); %hours minutes seconds
full.env.temp = SubEvent.Ta(:,1:3); % 

% Wind parameters
full.wind.speed = SubEvent.W.Speed(:,1:3);
full.wind.dir = SubEvent.W.Dir(:,1:3);

end
