% Process the full scale data of 30.03.2003
% ANM 22.05.2013

function [flcev] = processevent(input,ice,event)

% Convert from seconds to index in timevector
deltat = event.time(end)/length(event.time);
steady_start = ceil(input.steadyevent(1)/deltat);
steady_stop = ceil(input.steadyevent(2)/deltat);
%timevector
flcev.time = event.time(steady_start:steady_stop);

%% Ice thickness 
%measured
% measured thickness 30.03.2003
flcev.thick.tmeas = event.thickness.t;   
% measured timevector
flcev.thick.timemeas = event.thickness.timevector; 

% %calculated thickness
% calculated thickness 30.03.2003
% flcev.thick.calc = ice.thick(2176:2183);  
% flcev.thick.calctime = 1:1:input.proc.fmeas; %1 to 8, 1 is midnight

%% Forces
flcev.entireforce =  event.totalforce.sum;
flcev.totalforce = event.totalforce.sum(steady_start:steady_stop);

%% Displacements in 
flcev.displ = event.inclination(steady_start:steady_stop,:);

%% Accelerations
flcev.entireacc = [event.acc.lev19,event.acc.lev37];
flcev.acc = [event.acc.lev19(steady_start:steady_stop),...
    event.acc.lev37(steady_start:steady_stop)];

%% Fourier transform of accelerations at 19.6m and 37.1m
% make frequency vector given length of acceleration vectors and
% frequency/timestep in time vector
dt = event.time(2)-event.time(1);         %sample time
Fs = 1/dt;                                %sample frequency
L = length(event.acc.lev19(steady_start:steady_stop));   %length of signal

NFFT = 2^nextpow2(L); % Next power of 2 from length of y
flcev.fftacc19 = fft(event.acc.lev19(steady_start:steady_stop),NFFT)/L;
flcev.fftacc37 = fft(event.acc.lev37(steady_start:steady_stop),NFFT)/L;
flcev.freq = Fs/2*linspace(0,1,NFFT/2+1);
% amplitude of the one sided spectrum
flcev.amp19 = 2*abs(flcev.fftacc19(1:NFFT/2+1));
flcev.amp37 = 2*abs(flcev.fftacc37(1:NFFT/2+1));
end