%% Subfile for plotting of steady state event
function [] = steady(pathway4,time,phase_start,phase_stop, acc, totalforce, panelforce, loadseg, thickness, wind, env)

% Convert from seconds to index in timevector
deltat = time(end)/length(time)
steady_start = ceil(phase_start/deltat);
steady_stop = ceil(phase_stop/deltat);
%% steady state event
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Accelerations at 19.6 m and 37.1 m
figure(13)
subplot(2,1,1)
hold on
set(gca,'FontSize',14)
% plot(time(steady_start:steady_stop),totalforce.x(steady_start:steady_stop),'g')
% plot(time(steady_start:steady_stop),totalforce.y(steady_start:steady_stop),'r')
plot(time(steady_start:steady_stop),totalforce.sum(steady_start:steady_stop),'k')
axis([90,130,0,4500])
set(gca,'FontSize',14)
title('Total force for steady state phase')
ylabel('Force (kN)')
xlabel('Time (s)')
% legend('Fx','Fy','Ftotal')
grid on
box off
box off

subplot(2,1,2)
hold on
set(gca,'FontSize',14)
plot(time(steady_start:steady_stop),acc.lev19(steady_start:steady_stop),'b');
plot(time(steady_start:steady_stop),acc.lev37(steady_start:steady_stop),'k');
ylabel('Acceleration(m/s2)')
xlabel('Time (s)')
axis([phase_start,phase_stop,-3,3])
set(gca,'FontSize',14)
title('Acceleration @19.6m (blue) and @37.1m (black)')
grid on
box off
% set(gcf,'Visible','off')
saveas(gcf, strcat(pathway4,'\accelerations_IIV_SS.png'))

%% Fourier transform of accelerations at 19.6m and 37.1m
% make frequency vector given length of acceleration vectors and
% frequency/timestep in time vector
dt = time(2)-time(1);           %sample time
Fs = 1/dt;                      %sample frequency
L = length(acc.lev19(steady_start:steady_stop));          %length of signal

NFFT = 2^nextpow2(L); % Next power of 2 from length of y
fourieracc.lev19 = fft(acc.lev19(steady_start:steady_stop),NFFT)/L;
fourieracc.lev37 = fft(acc.lev37(steady_start:steady_stop),NFFT)/L;
freq = Fs/2*linspace(0,1,NFFT/2+1);
% amplitude of the one sided spectrum
fourieracc.amp19 = 2*abs(fourieracc.lev19(1:NFFT/2+1));
fourieracc.amp37 = 2*abs(fourieracc.lev37(1:NFFT/2+1));
% Plot single-sided amplitude spectrum.
figure(14)
set(gca,'FontSize',14)
subplot(2,1,1)
plot(freq,fourieracc.amp19)
title('Single-Sided Amplitude Spectrum of acceleration at 19.6 m for steady state phase')
axis([0,5,0,0.4])
set(gca,'FontSize',14)
xlabel('Frequency, f (Hz)')
ylabel('|Acc(f)|')
grid on
box off

subplot(2,1,2)
set(gca,'FontSize',14)
plot(freq,fourieracc.amp37)
set(gca,'FontSize',14)
title('Single-Sided Amplitude Spectrum of acceleration at 37.1 m for steady state phase')
axis([0,5,0,0.4])
xlabel('Frequency, f (Hz)')
ylabel('|Acc(f)|')
grid on
box off
saveas(gcf, strcat(pathway4,'\fftaccelerations_steady_IIV_SS.png'))

%Plot single sided spectrums w/ label on maximum value
figure(15)
set(gca,'FontSize',14)
subplot(2,1,1)
plot(freq,fourieracc.amp19)
set(gca,'FontSize',14)
title('Single-Sided Amplitude Spectrum of acceleration at 19.6 m for steady state phase')
set(gca,'FontSize',14)
axis([0,5,0,0.4])
xlabel('Frequency, f (Hz)')
ylabel('|Acc(f)|')
box off
hold on;
index=find(fourieracc.amp19==max(fourieracc.amp19));
mainfreqStr1=num2str(freq(index));
plot(freq(index),fourieracc.amp19(index),'r.', 'MarkerSize',25);
set(gca,'FontSize',14)
text(freq(index)+0.2,fourieracc.amp19(index),['Frequency = ',mainfreqStr1,'Hz']);

subplot(2,1,2)
set(gca,'FontSize',14)
plot(freq,fourieracc.amp37)
title('Single-Sided Amplitude Spectrum of acceleration at 37.1 m for steady state phase')
axis([0,5,0,0.4])
xlabel('Frequency, f (Hz)')
ylabel('|Acc(f)|')
box off
hold on;
index=find(fourieracc.amp37==max(fourieracc.amp37));
mainfreqStr2=num2str(freq(index));
plot(freq(index),fourieracc.amp37(index),'r.', 'MarkerSize',25);
set(gca,'FontSize',14)
text(freq(index)+0.2,fourieracc.amp37(index),['Frequency = ',mainfreqStr2,'Hz']);
set(gca,'FontSize',14)
saveas(gcf, strcat(pathway4,'\fftaccelerationswlabel_steady_IIV_SS.png'))
hold off;


%% Forces 
% Total forces
figure(16)
hold on
plot(time(steady_start:steady_stop),totalforce.x(steady_start:steady_stop),'g')
plot(time(steady_start:steady_stop),totalforce.y(steady_start:steady_stop),'r')
plot(time(steady_start:steady_stop),totalforce.sum(steady_start:steady_stop),'k')
axis([90,130,0,4500])
title('Force')
ylabel('force (N)')
xlabel('Time (s)')
legend('Fx','Fy','Ftotal')
grid on
box off
% set(gcf,'Visible','off')
saveas(gcf, strcat(pathway4,'\forces_IIV_SS.png'))


% Panel forces
figure(17)
subplot(3,1,1)
plot(time(steady_start:steady_stop),panelforce.p1(steady_start:steady_stop),'b-')
hold on
plot(time(steady_start:steady_stop),panelforce.p2(steady_start:steady_stop),'g-')
plot(time(steady_start:steady_stop),panelforce.p3(steady_start:steady_stop),'r-')
box off
grid on
axis([phase_start,phase_stop,-20,1500])
title('Panelforces (0 is North, 90 is East)')
ylabel('Load (kN)')
legend('  0 ','  18 ','  36 ',-1)

subplot(3,1,2)
plot(time(steady_start:steady_stop),panelforce.p4(steady_start:steady_stop),'b-')
hold on
plot(time(steady_start:steady_stop),panelforce.p5(steady_start:steady_stop),'g-')
plot(time(steady_start:steady_stop),panelforce.p6(steady_start:steady_stop),'r-')
box off
grid on
axis([phase_start,phase_stop,-20,1500])
ylabel('Load (kN)')
legend('  54 ','  72 ','  90 ',-1)

subplot(3,1,3)
plot(time(steady_start:steady_stop),panelforce.p7(steady_start:steady_stop),'b-')
hold on
plot(time(steady_start:steady_stop),panelforce.p8(steady_start:steady_stop),'g-')
plot(time(steady_start:steady_stop),panelforce.p9(steady_start:steady_stop),'r-')
box off
grid on
axis([phase_start,phase_stop,-20,1500])
ylabel('Load (kN)')
xlabel('Time(s)')
legend('108','126','144',-1)
% set(gcf,'Visible','off')
saveas(gcf, strcat(pathway4,'\panelforces_IIV_SS.png'))

%% Environmental parameters

%
figure(18)
hold on
plot(time(steady_start:steady_stop),totalforce.sum(steady_start:steady_stop),'k')
axis([90,130,0,4500])
title('Force')
ylabel('force (kN)')
xlabel('Time (s)')
grid on
box off
% set(gcf,'Visible','off')
saveas(gcf, strcat(pathway4,'\forcevsthickness_IIV_SS.png'))


figure(19)
hold on
plot(thickness.t,'k')
plot(thickness.diff,'r')
% axis([0,5,-2,2])
title('Measured ice sheet thickness')
ylabel('force (m)')
xlabel('Time (s)')
grid on
box off
% set(gcf,'Visible','off')
saveas(gcf, strcat(pathway4,'\thickness_IIV_SS.png'))
end